package LATMOS::Accounts::Web::Controller::Json::Stat;
use Moose;
use namespace::autoclean;

BEGIN { extends 'Catalyst::Controller'; }

=head1 NAME

LATMOS::Accounts::Web::Controller::Json::Stat - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=cut


=head2 index

=cut

sub employment :Local :Args(0) {
    my ( $self, $c ) = @_;

    my $base = $c->model('Accounts')->db;

    my @results = ();

    foreach my $contrat ($base->search_objects('group', 'sutype=contrattype')) {
        my $ocontrat = $base->get_object('group', $contrat);
        my $count = scalar( $base->search_objects('user', "memberOf=$contrat", 'active=1') );

        push(@results, [ ($ocontrat->get_attributes('label') || $contrat), $count ]);
    }

    $c->stash->{data} = [ sort { $b->[1] <=> $a->[1] } @results ];
}

sub dpmt :Local :Args(0) {
    my ( $self, $c ) = @_;

    my $base = $c->model('Accounts')->db;

    my @results = ();

    foreach my $dpmt ($base->search_objects('group', 'sutype=dpmt')) {
        my $odpmt = $base->get_object('group', $dpmt);
        my $count = scalar( $base->search_objects('user', "department=$dpmt", 'active=1') );

        push(@results, [ $dpmt, $count ]);
    }

    $c->stash->{data} = [ sort { $b->[1] <=> $a->[1] } @results ];
}

sub manager :Local :Args(0) {
    my ( $self, $c ) = @_;

    my $base = $c->model('Accounts')->db;

    my @results = ();

    my %active = map { $_ => 1 } $base->search_objects('user', 'active=1', 'givenName=*');

    my %managed = $base->attributes_summary_by_object('user', 'managerContact');

    my %managers = ();

    my $total = 0;

    foreach my $user (sort keys %managed) {
        $active{$user} or next;
        foreach (@{ $managed{ $user } }) {
            $active{$_} or next;
            $managers{$_} ||= 0;
            $managers{$_} ++;
            $total++;
        }
    }

    my $minreport = $c->req->param('min');
    my $others = 0;

    foreach my $user (sort { $managers{$b} <=> $managers{$a} } keys %managers) {
        if ($minreport && $managers{$user} / $total * 100 < $minreport) {
            $others++;
            next;
        }
        push(@results, [ $user, $managers{$user} ]);
    }

    push(@results, [ 'Others', $others ]) if ($others); 

    $c->stash->{data} = \@results;
}




=encoding utf8

=head1 AUTHOR

Olivier Thauvin

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
